% Square wave pulsing of Knowm M-MSS memristor model showing incremental conductance change
%
% Post processing of data to show individual current response to pulse at (-0.1 V to -1.0 V, 0V, 1.0 V to 0.1 V)
% in 0.1 V steps
%
% Note: Pulse parameters Pwidth and Period must be set to match Rectange Pulse source in Qucs-S schematic
%
% Copyright 2017 (c) 2017 by Michael Arendall <miche.arendall@gmail.com>
% Published under GNU General Public License (GPL V3). No warranty at all.
%
% Created: 03/21/2017  by Michael Arendall  miche.arendall@gmail.com
% Modified: 04/01/2017 by Michael Arendall -  implemented createPulseNDataSet() function call to optimize
% script by adding reusable function
%
clear;
Data    = "knowm_mr_pulse_bipolar_incr.dat.xyce";
qdset   = loadQucsNDataSet(Data);
%showQucsDataSet(qdset);
%
% parse qucs dataset
qvect = parseQucsNDataSet(qdset);
for i = 1:length(qdset)
    fprintf(1, 'i = %d vector = %s len = %d\n', i, qvect(i).name, qvect(i).len);
end
% data vectors
plno = [];
iMrm = [];  % memristor current
vMrm = [];  % memristor voltage
rMrm = [];  % memristor resistance

% pulse parameters
pwidth = 0.5e-6;
period = 1e-6;
tick = pwidth/2;
%
%
% get pulse data from parsed Qucs dataSet vectors (qvect)
% provide pulse width and period for sampling data vector
%
pl = createPulseNDataSet(pwidth, period, qvect);

% debug
fprintf (1, 'pl_len = %d\n', length(pl));
%
% load local arrays with pulse data structure info
for p = 1:length(pl)
    plno(p) = pl(p).no;
    iMrm(p) = pl(p).iMrm;
    vMrm(p) = pl(p).vMrm;
    rMrm(p) = pl(p).rMrm;

    % debug
    fprintf(1,'pulse_no = %d  voltage = %g current = %g resistance = %g\n', plno(p), vMrm(p), iMrm(p), rMrm(p));
end

%
% plot I(PR1) vs. Pulse no.
%
figure(1)
Xstart = 1;
Xstop = length(plno);
plotCartesian2D("plot", plno, iMrm, "Pulse No.", "Memristor Current (A)", Xstart, Xstop, 2);


figure(2)
Xstart = 1;
Xstop = length(plno);
plotCartesian2D("plot", plno, rMrm, "Pulse No.", "Memristor Resistance (R)", Xstart, Xstop, 2);

%
% end knowm_mr_pulse_bipolar_incr
